@@ -25,7 +25,8 @@ rho.file <- function(
   ScSKappaThreshold = 0.9,
   ScSKappaMin = .40,
   ScSPrecisionMin = 0.6,
-  ScSPrecisionMax = 1
+  ScSPrecisionMax = 1,
+  method = "standard"
 ) {
   setFile = utils::read.csv(x)
   set = as.matrix(setFile[,c(col1, col2)])
